@@ -80,7 +80,7 @@ namespace giac {
       if (b.front().type==_VECT) {
 	// ddeg should be even if b0 is a _POLY1
 	if (ddeg%2==0)
-	  *logptr(contextptr) << gettext("Singular parametric Sturm sequence ") << a << "/" << b << endl;
+	  *logptr(contextptr) << gettext("Singular parametric Sturm sequence ") << a << "/" << b << '\n';
       }
       else
 	b0=abs(b.front(),contextptr); 
@@ -310,7 +310,7 @@ namespace giac {
 	if (res[6].type==_VECT && !equalposcomp(*res[6]._VECTptr,0))
 	  return res;
 	else
-	  CERR << "list of quotients is not regular" << endl;
+	  CERR << "list of quotients is not regular" << '\n';
       }
     }
     */
@@ -329,11 +329,11 @@ namespace giac {
     gen g=csturm_seq(S,R,listquo,coeffP,coeffR,contextptr);
     int typeseq=-1;
     if (debug_infolevel)
-      *logptr(contextptr)  << "segment " << a << ".." << b << ", im/re:" << S << "|" << R << ", gcd:" << g << endl;
+      *logptr(contextptr)  << "segment " << a << ".." << b << ", im/re:" << S << "|" << R << ", gcd:" << g << '\n';
     if (g.type==_VECT && g._VECTptr->size()==P.size()){
       // if g==P (up to a constant), use real Sturm sequences
       if (debug_infolevel)
-	*logptr(contextptr)  << "Real-kind roots: " << g << endl;
+	*logptr(contextptr)  << "Real-kind roots: " << g << '\n';
       R=*g._VECTptr;
       S=derivative(R);
       g=csturm_seq(S,R,listquo,coeffP,coeffR,contextptr);
@@ -389,7 +389,7 @@ namespace giac {
     // res += tmp;
     res=(debut?1:signe)*res;
     if (debug_infolevel)
-      *logptr(contextptr)  << "segment " << a << ".." << b << " index contribution " << res << endl;
+      *logptr(contextptr)  << "segment " << a << ".." << b << " index contribution " << res << '\n';
     return res;
   }
 
@@ -836,11 +836,11 @@ namespace giac {
   static int complex_roots(const modpoly & P,const gen & a0,const gen & b0,const gen & a1,const gen & b1,const vecteur & seq1,const vecteur & seq2,const vecteur & seq3,const vecteur & seq4,vecteur & realroots,vecteur & complexroots,double eps,vecteur & horiz_sturm,vecteur & vert_sturm){
     int n=csturm_square(P,a0,b0,a1,b1,seq1,seq2,seq3,seq4,context0);
     if (debug_infolevel && n)
-      CERR << a0 << "," << b0 << ".." << a1 << "," << b1 << ":" << n/2 << endl;
+      CERR << a0 << "," << b0 << ".." << a1 << "," << b1 << ":" << n/2 << '\n';
     if (n<=0)
       return 2*n;
     if (eps<=0){
-      *logptr(context0) << gettext("Bad precision, using 1e-12 instead of ")+print_DOUBLE_(eps,14) << endl;
+      *logptr(context0) << gettext("Bad precision, using 1e-12 instead of ")+print_DOUBLE_(eps,14) << '\n';
       eps=1e-12;
     }
     if (is_strictly_greater(eps,a1-a0,context0) && is_strictly_greater(eps,b1-b0,context0)){
@@ -1032,7 +1032,7 @@ namespace giac {
       }
       sumdr2 += delta;
       if (!is_greater(deltar*deltar,sumdr2,context0)){
-	CERR << "Unable to certify " << v[i] << endl ;
+	CERR << "Unable to certify " << v[i] << '\n' ;
 	return false;
       }
       if (N<P.size()-epsn){
@@ -1084,7 +1084,7 @@ namespace giac {
 	if (!is_exactly_zero(vradius[i]))
 	  vradius[i]=min(epsg,pow(plus_two,int(evalf_double(ln(vradius[i],context0),1,context0)._DOUBLE_val/std::log(2.))+1),context0);
 	if (debug_infolevel)
-	  CERR << CLOCK() << " isolated " << r << " radius " << vradius[i] << endl;
+	  CERR << CLOCK() << " isolated " << r << " radius " << vradius[i] << '\n';
 	if (nextconj){
 	  v[i+1]=conj(r,context0);
 	  vradius[i+1]=vradius[i];
@@ -1094,7 +1094,7 @@ namespace giac {
       }
       sumdr2 += delta;
       if (!is_greater(deltar*deltar,sumdr2,context0)){
-	CERR << "Unable to certify " << v[i] << endl ;
+	CERR << "Unable to certify " << v[i] << '\n' ;
 	return false;
       }
       if (N<int(P.size())-epsn){
@@ -1123,7 +1123,7 @@ namespace giac {
   vecteur complex_roots(const modpoly & P,const gen & a0,const gen & b0,const gen & a1,const gen & b1,bool complexe,double eps,bool use_proot){
     if (P.empty())
       return P;
-    eps=std::abs(eps);
+    eps=absdouble(eps);
     if (eps>1e-6)
       eps=1e-6;
     if (use_proot){
@@ -1137,10 +1137,10 @@ namespace giac {
       for (;n<400;n*=2){
 	double cureps=std::pow(2.0,-n);
 	if (debug_infolevel)
-	  CERR << CLOCK() << " proot at precision " << cureps << endl;
+	  CERR << CLOCK() << " proot at precision " << cureps << '\n';
 	vecteur v=proot(P,cureps,n);
 	if (debug_infolevel)
-	  CERR << CLOCK() << " proot end at precision " << cureps << endl;
+	  CERR << CLOCK() << " proot end at precision " << cureps << '\n';
 	vecteur vradius(v.size());
 	unsigned i=0;
 	int kmax=int(std::log(eps)/std::log(cureps))+4;
@@ -1184,7 +1184,7 @@ namespace giac {
 	  return res;
 	} // end if i==v.size()
       } // end for n
-      CERR << "proot isolation did not work, trying complex Sturm sequences" << endl;
+      CERR << "proot isolation did not work, trying complex Sturm sequences" << '\n';
     }
     bool aplati=(a0==a1) && (b0==b1);
     if (!aplati && complexe && (a0==a1 || b0==b1) )
@@ -1341,7 +1341,7 @@ namespace giac {
     // return _sorta(complexroot(g,true,contextptr),contextptr);
   }
   static const char _complexroot_s []="complexroot";
-  static define_unary_function_eval (__complexroot,&giac::_complexroot,_complexroot_s);
+  static define_unary_function_eval (__complexroot,&_complexroot,_complexroot_s);
   define_unary_function_ptr5( at_complexroot ,alias_at_complexroot,&__complexroot,0,true);
 
   gen _realroot(const gen & g,GIAC_CONTEXT){
@@ -1376,7 +1376,7 @@ namespace giac {
     return v;
   }
   static const char _realroot_s []="realroot";
-  static define_unary_function_eval (__realroot,&giac::_realroot,_realroot_s);
+  static define_unary_function_eval (__realroot,&_realroot,_realroot_s);
   define_unary_function_ptr5( at_realroot ,alias_at_realroot,&__realroot,0,true);
 
   static vecteur crationalroot(const gen & g0,bool complexe){
@@ -1424,7 +1424,7 @@ namespace giac {
     return crationalroot(g,true);
   }
   static const char _crationalroot_s []="crationalroot";
-  static define_unary_function_eval (__crationalroot,&giac::_crationalroot,_crationalroot_s);
+  static define_unary_function_eval (__crationalroot,&_crationalroot,_crationalroot_s);
   define_unary_function_ptr5( at_crationalroot ,alias_at_crationalroot,&__crationalroot,0,true);
 
   gen _rationalroot(const gen & g,GIAC_CONTEXT){
@@ -1432,7 +1432,7 @@ namespace giac {
     return crationalroot(g,false);
   }
   static const char _rationalroot_s []="rationalroot";
-  static define_unary_function_eval (__rationalroot,&giac::_rationalroot,_rationalroot_s);
+  static define_unary_function_eval (__rationalroot,&_rationalroot,_rationalroot_s);
   define_unary_function_ptr5( at_rationalroot ,alias_at_rationalroot,&__rationalroot,0,true);
 
   // convert numerator of g to a list
@@ -1527,7 +1527,7 @@ namespace giac {
 	  mant=evalf_double(cl[i],1,contextptr)._DOUBLE_val;
 	}
       }
-      mant=std::log(std::abs(mant));
+      mant=std::log(absdouble(mant));
       cllnabsmant[i]=mant;
       clexpo[i]=expo;
     }
@@ -1588,7 +1588,7 @@ namespace giac {
     return posubLMQ(v,contextptr);
   }
   static const char _posubLMQ_s []="posubLMQ";
-  static define_unary_function_eval (__posubLMQ,&giac::_posubLMQ,_posubLMQ_s);
+  static define_unary_function_eval (__posubLMQ,&_posubLMQ,_posubLMQ_s);
   define_unary_function_ptr5( at_posubLMQ ,alias_at_posubLMQ,&__posubLMQ,0,true);
 
   gen poslbdLMQ(const modpoly & P,GIAC_CONTEXT){
@@ -1645,7 +1645,7 @@ namespace giac {
     return poslbdLMQ(v,contextptr);
   }
   static const char _poslbdLMQ_s []="poslbdLMQ";
-  static define_unary_function_eval (__poslbdLMQ,&giac::_poslbdLMQ,_poslbdLMQ_s);
+  static define_unary_function_eval (__poslbdLMQ,&_poslbdLMQ,_poslbdLMQ_s);
   define_unary_function_ptr5( at_poslbdLMQ ,alias_at_poslbdLMQ,&__poslbdLMQ,0,true);
 
   vecteur makeinterval(const gen & a,const gen & b){
@@ -1797,7 +1797,7 @@ namespace giac {
     return VAS_positive_roots(v,1,0,0,1,contextptr);
   }
   static const char _VAS_positive_s []="VAS_positive";
-  static define_unary_function_eval (__VAS_positive,&giac::_VAS_positive,_VAS_positive_s);
+  static define_unary_function_eval (__VAS_positive,&_VAS_positive,_VAS_positive_s);
   define_unary_function_ptr5( at_VAS_positive ,alias_at_VAS_positive,&__VAS_positive,0,true);
 
   // square-free factorization of p, then remove all exponents
@@ -1863,7 +1863,7 @@ namespace giac {
     return vas(v,contextptr);
   }
   static const char _VAS_s []="VAS";
-  static define_unary_function_eval (__VAS,&giac::_VAS,_VAS_s);
+  static define_unary_function_eval (__VAS,&_VAS,_VAS_s);
   define_unary_function_ptr5( at_VAS ,alias_at_VAS,&__VAS,0,true);
 
   static const double bisection_newton_eps=1e-3;
