@@ -4,7 +4,11 @@
 #include "config.h"
 #endif
 #include "first.h"
-
+#ifdef KHICAS
+int main(){
+  return 0;
+}
+#else
 /*
  *  Copyright (C) 2000,2014 B. Parisse, Institut Fourier, 38402 St Martin d'Heres
  *
@@ -160,6 +164,7 @@ static int texmacs_counter= 0;
 using namespace giac;
 #define STDIN_FILENO 0
 namespace xcas {
+  /*
   void icas_eval(giac::gen & g,giac::gen & gg,int & reading_file,std::string &filename,giac::context * contextptr){
     gg=protecteval(g,10,contextptr);
   }
@@ -167,12 +172,13 @@ namespace xcas {
   bool fltk_view(const giac::gen & g,giac::gen & ge,const std::string & filename,std::string & figure_filename,int file_type,const giac::context *contextptr){
     return false;
   }
+  */
 }
 
 #else
 void ctrl_c_signal_handler(int signum){
   giac::ctrl_c=true;
-  cerr << "icas/giac process " << getpid() << ", Ctrl-C pressed, interruption requested" << endl;
+  cerr << "icas/giac process " << getpid() << ", Ctrl-C pressed, interruption requested" << '\n';
 }
 #endif
 
@@ -264,7 +270,7 @@ void texmacs_graph_output(const giac::gen & g,giac::gen & gg,std::string & figfi
     // putchar(TEXMACS_DATA_END);
     flush_stdout();
     // ofstream log("log");
-    // log << g << endl;
+    // log << g << '\n';
   }
 }
 
@@ -312,7 +318,7 @@ void check_browser_help(const giac::gen & g){
       f=f._SYMBptr->sommet;
     if (f.type==giac::_FUNC)
       s=f._FUNCptr->ptr()->s;
-#if !defined EMCC && !defined NSPIRE_NEWLIB
+#if !defined EMCC && !defined NSPIRE_NEWLIB && !defined KHICAS
     giac::html_vtt=giac::html_help(giac::html_mtt,s);
 #ifndef HAVE_NO_SYSTEM
     if (!giac::html_vtt.empty())
@@ -377,7 +383,12 @@ string ltgt(const string & s){
   return res;
 }
 
-void verb(std::string & warn,int line,ostream & out,std::string cmd,const std::string & infile,int & texmacs_counter,bool slider,giac::context * contextptr,ostream * checkptr,std::ostream * checkptrin){
+void verb(std::string & warn,int line,ostream & out,std::string cmd_,const std::string & infile,int & texmacs_counter,bool slider,giac::context * contextptr,ostream * checkptr,std::ostream * checkptrin){
+  std::string cmd;
+  if (giac::python_compat(contextptr))
+    cmd="@@"+cmd_;
+  else
+    cmd=cmd_;
   giac::gen g(cmd,contextptr),gg;
   string gs=cmd;
   split(cmd,50);
@@ -386,9 +397,9 @@ void verb(std::string & warn,int line,ostream & out,std::string cmd,const std::s
   if (pos<0 || pos>=cmd.size())
     pos=cmd.find('|');
   if (pos<0 || pos>=cmd.size())
-    out << "\\verb|"<<cmd<<"|\\\\"<<endl;
+    out << "\\verb|"<<cmd<<"|\\\\"<<'\n';
   else
-    out << "\\begin{verbatim}\n" << cmd << "\\end{verbatim}" << endl;
+    out << "\\begin{verbatim}\n" << cmd << "\\end{verbatim}" << '\n';
   int reading_file=0;
   std::string filename,tmp;
   xcas::icas_eval(g,gg,reading_file,filename,contextptr);
@@ -400,14 +411,14 @@ void verb(std::string & warn,int line,ostream & out,std::string cmd,const std::s
     }
     if (ss && gs[ss-1]!=';')
       gs += ';';
-    *checkptrin << gs << endl ;
+    *checkptrin << gs << '\n' ;
   }
-  if (checkptr) *checkptr << gg << endl;
+  if (checkptr) *checkptr << gg << '\n';
   int graph_output=graph_output_type(gg);
   if (graph_output){
     filename=infile+giac::print_INT_(texmacs_counter)+".eps";
     if (xcas::fltk_view(g,gg,filename,tmp,-1,contextptr)){
-      out << "\n\\begin{center}\n\\includegraphics[width=0.8\\linewidth]{" << filename << "}\n\\end{center}\n"<<std::endl;
+      out << "\n\\begin{center}\n\\includegraphics[width=0.8\\linewidth]{" << filename << "}\n\\end{center}\n"<<'\n';
       ++texmacs_counter;
     }
   }
@@ -428,13 +439,13 @@ void verb(std::string & warn,int line,ostream & out,std::string cmd,const std::s
     }
     gg=giac::string2gen(giac::gen2tex(gg,contextptr),false);
     std::string s=(gg.type==giac::_STRNG)?(*gg._STRNGptr):gg.print(contextptr);
-    out << "$$" << s << "$$" << std::endl;
+    out << "$$" << s << "$$" << '\n';
   }  
 }
 
 void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::ostream * checkptrin,bool dohevea){
-  COUT << "Giac pdflatex and HTML5 output" << endl;
-  COUT << "Partly inspired from pgiac by Jean-Michel Sarlat" << endl;
+  COUT << "Giac pdflatex and HTML5 output" << '\n';
+  COUT << "Partly inspired from pgiac by Jean-Michel Sarlat" << '\n';
   if (!giac::is_file_available("giac.tex")){
     if (giac::is_file_available("/usr/share/giac/doc/giac.tex"))
       giac::system_no_deprecation("cp /usr/share/giac/doc/giac.tex .");
@@ -467,6 +478,7 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
   char buf[BUFFER_SIZE+1];
   buf[BUFFER_SIZE]=0;
   bool inside=false,inprog=false,inverb=false;
+  int inhevea=0; // 1: \ifhevea, -1: \else
   string prg;
   for (;;){
     if (in.eof())
@@ -474,28 +486,54 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
     in.getline(buf,BUFFER_SIZE,'\n');++line;
     string s(buf);
     if (s.empty() && inside)
-      out << endl;
+      out << '\n';
     for (;!s.empty();){
       int ss=s.size();
       int pos=0;
+      if (inhevea==1){
+	pos=s.find("\\fi");
+	if (pos>=0 && pos<ss){
+	  inhevea=0;
+	  break;
+	}
+	pos=s.find("\\else");
+	if (pos>=0 && pos<ss){
+	  inhevea=-1;
+	}
+	break;
+      }
+      if (inhevea){
+	pos=s.find("\\fi");
+	if (pos>=0 && pos<ss){
+	  inhevea=0;
+	  break;
+	}
+      }
+      else {
+	pos=s.find("\\ifhevea");
+	if (pos>=0 && pos<ss){
+	  inhevea=1;
+	  break;
+	}
+      }
       if (inside){
 	if (!inverb){
 	  pos=s.find("\\verb");
 	  if (pos>=0 && pos<ss){
-	    out << s << endl; // ignore filtering if \verb inside
+	    out << s << '\n'; // ignore filtering if \verb inside
 	    break;
 	  }
 	  pos=s.find("\\begin{verbatim}");
 	  if (pos>=0 && pos<ss){
 	    inverb=true;
-	    out << s << endl;
+	    out << s << '\n';
 	    break;
 	  }
 	}
 	pos=s.find("\\end{verbatim}");
 	if (pos>=0 && pos<ss){
 	  inverb=false;
-	  out << s << endl;
+	  out << s << '\n';
 	  break;
 	}
       }
@@ -512,34 +550,34 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
       if (!inside){
 	int pos=s.find("\\begin{document}");
 	if (pos>=0 && pos<ss){
-	  out << "\\usepackage{graphicx}\n\\usepackage{xcolor}\n\\newcommand{\\MarqueCommandeGiac}[1]{\n\\color[HTML]{8B7500}$\\rightarrow$}\n\\newcommand{\\MarqueLaTeXGiac}{%\n\\color[HTML]{08868B}}\n\\newcommand{\\InscriptionFigureGiac}[1]{%\n\\begin{center}\n\\includegraphics[width=0.7\\linewidth]{#1}\n\\end{center}\n}" << endl;
+	  out << "\\usepackage{graphicx}\n\\usepackage{xcolor}\n\\newcommand{\\MarqueCommandeGiac}[1]{\n\\color[HTML]{8B7500}$\\rightarrow$}\n\\newcommand{\\MarqueLaTeXGiac}{%\n\\color[HTML]{08868B}}\n\\newcommand{\\InscriptionFigureGiac}[1]{%\n\\begin{center}\n\\includegraphics[width=0.7\\linewidth]{#1}\n\\end{center}\n}" << '\n';
 	  inside=true;
 	}
       }
       else {
 	int pos=s.find("\\end{document}");
 	if (pos>=0 && pos<ss){
-	  out << s << endl;
+	  out << s << '\n';
 	  out.close();
-	  COUT << "File " << outfile << " created" << outfile << endl << "Then I will run pdflatex " << giac::remove_extension(outfile) << endl ;
+	  COUT << "File " << outfile << " created" << outfile << '\n' << "Then I will run pdflatex " << giac::remove_extension(outfile) << '\n' ;
 	  if (dohevea){
 	    std::string cmd="hevea -fix "+infile_+" &";
-	    COUT << "Running " << cmd << endl;
+	    COUT << "Running " << cmd << '\n';
 	    giac::system_no_deprecation(cmd.c_str());
 	  }
 	  else
-	    COUT << "For HTML5 output, you can run\nhevea -fix " << infile_ << endl;
+	    COUT << "For HTML5 output, you can run\nhevea -fix " << infile_ << '\n';
 	  std::string cmd="makeindex "+giac::remove_extension(outfile);
 	  giac::system_no_deprecation(cmd.c_str());
 	  cmd=("pdflatex "+giac::remove_extension(outfile)+" && mv "+giac::remove_extension(outfile)+".pdf "+infile_+".pdf");
-	  COUT << cmd << endl;
+	  COUT << cmd << '\n';
 	  giac::system_no_deprecation(cmd.c_str());
 	  if (!warn.empty()){
-	    COUT << "*********************************" << endl;
-	    COUT << "*********************************" << endl;
-	    COUT << "Please take care of the warnings below. Press ENTER to continue" << endl << warn;
-	    COUT << "*********************************" << endl;	    
-	    COUT << "*********************************" << endl;
+	    COUT << "*********************************" << '\n';
+	    COUT << "*********************************" << '\n';
+	    COUT << "Please take care of the warnings below. Press ENTER to continue" << '\n' << warn;
+	    COUT << "*********************************" << '\n';	    
+	    COUT << "*********************************" << '\n';
 	  }
 	  return;
 	}
@@ -547,13 +585,27 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
       if (inprog){
 	pos=s.find("\\end{giacprog}");
 	int decal=16;
-	if (pos<0 || pos>=ss)
+	bool hide=false;
+	if (pos<0 || pos>=ss){
 	  pos=s.find("\\end{giaconload}");
+	  if (pos<0 || pos>=ss){
+	    pos=s.find("\\end{giaconloadhide}");
+	    decal=20;
+	    hide=true;
+	  }
+	}
 	else
 	  decal=14;
 	if (pos>=0 && pos<ss){
 	  prg += s.substr(0,pos);
-	  out << "\\begin{verbatim}\n" << prg << "\\end{verbatim}" << endl;
+	  if (hide){
+	    if (prg.substr(prg.size()-3,3)==":;\n")
+	      prg=prg.substr(0,prg.size()-3);
+	  }
+	  else
+	    out << "\\begin{verbatim}\n" << prg << "\\end{verbatim}" << '\n';
+ 	  if (giac::python_compat(&ct))
+	    prg="@@"+prg;
 	  giac::gen g(prg,&ct),gg;
 	  int reading_file=0;
 	  std::string filename;
@@ -567,11 +619,20 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	    }
 	    if (ss && gs[ss-1]!=';')
 	      gs += ';';
-	    *checkptrin << gs << endl ;
+	    *checkptrin << gs << '\n' ;
 	  }
-	  if (checkptr) *checkptr << gg << endl;
+	  if (checkptr) *checkptr << gg << '\n';
 	  s=s.substr(pos+decal,ss-decal-pos);
 	  inprog=false;
+	  int graph_output=graph_output_type(gg);
+	  if (graph_output){
+	    filename=giac::remove_extension(infile)+giac::print_INT_(texmacs_counter)+".eps";
+	    string tmp;
+	    if (xcas::fltk_view(g,gg,filename,tmp,-1,&ct)){
+	      out << "\n\\begin{center}\n\\includegraphics[width=0.8\\linewidth]{" << filename << "}\n\\end{center}\n"<<'\n';
+	      ++texmacs_counter;
+	    }
+	  }
 	  continue;
 	}
 	prg += s + '\n';
@@ -591,11 +652,23 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	inprog=true;
 	continue;
       }
+      pos=s.find("\\begin{giaconloadhide}");
+      if (pos>=0 && pos<ss){
+	prg = "";
+	s=s.substr(pos+22,ss-22-pos);
+	inprog=true;
+	continue;
+      }
       pos=s.find("\\giac");
       if (inside && pos>=0 && pos<ss){
-	out << s.substr(0,pos) << endl;
+	out << s.substr(0,pos) << '\n';
 	s=s.substr(pos,ss-pos);
 	ss=s.size();
+	if (s=="\\giacpython" ){
+	  giac::python_compat(1,&ct);
+	  s=s.substr(pos+11,ss-pos-11);
+	  continue;
+	}
 	bool invalid=false;
 	int pos1=s.find("{"),pos2=s.find("}");
 	while ( (pos1>=0 && pos1<ss ) && (pos2<0 || pos2>=ss)){
@@ -608,7 +681,7 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	  pos2=s.find("}");
 	}
 	if (ss>10 && s.substr(1,8)=="giaclink" && pos1>=0 && pos1<ss && pos2>=0 && pos2<ss){
-	  out << s.substr(0,pos2+1) << endl;
+	  out << s.substr(0,pos2+1) << '\n';
 	  s=s.substr(pos2+1,ss-pos2-1);
 	  continue;
 	}
@@ -680,14 +753,14 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	  continue;
 	}
 	else
-	  COUT << "Invalid giac command " << s << endl;
+	  COUT << "Invalid giac command " << s << '\n';
       }
-      out << s << endl;
+      out << s << '\n';
       break;
     }
   }
   out.close();
-  COUT << "Missing \\end{document}. File " << outfile << " created" << endl;
+  COUT << "Missing \\end{document}. File " << outfile << " created" << '\n';
   //giac::system_no_deprecation(("pgiac "+outfile).c_str());
 }
 
@@ -712,20 +785,20 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	if (!inverb){
 	  pos=s.find("\\verb");
 	  if (pos>=0 && pos<ss){
-	    out << s << endl; // ignore filtering if \verb inside
+	    out << s << '\n'; // ignore filtering if \verb inside
 	    break;
 	  }
 	  pos=s.find("\\begin{verbatim}");
 	  if (pos>=0 && pos<ss){
 	    inverb=true;
-	    out << s << endl;
+	    out << s << '\n';
 	    break;
 	  }
 	}
 	pos=s.find("\\end{verbatim}");
 	if (pos>=0 && pos<ss){
 	  inverb=false;
-	  out << s << endl;
+	  out << s << '\n';
 	  break;
 	}
       }
@@ -740,20 +813,20 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
       if (!inside){
 	int pos=s.find("\\begin{document}");
 	if (pos>=0 && pos<ss){
-	  out << "\\usepackage{graphicx}\n\\usepackage{xcolor}\n\\newcommand{\\MarqueCommandeGiac}[1]{\n\\color[HTML]{8B7500}$\\rightarrow$}\n\\newcommand{\\MarqueLaTeXGiac}{%\n\\color[HTML]{08868B}}\n\\newcommand{\\InscriptionFigureGiac}[1]{%\n\\begin{center}\n\\includegraphics[width=0.7\\linewidth]{#1}\n\\end{center}\n}" << endl;
+	  out << "\\usepackage{graphicx}\n\\usepackage{xcolor}\n\\newcommand{\\MarqueCommandeGiac}[1]{\n\\color[HTML]{8B7500}$\\rightarrow$}\n\\newcommand{\\MarqueLaTeXGiac}{%\n\\color[HTML]{08868B}}\n\\newcommand{\\InscriptionFigureGiac}[1]{%\n\\begin{center}\n\\includegraphics[width=0.7\\linewidth]{#1}\n\\end{center}\n}" << '\n';
 	  inside=true;
 	}
       }
       else {
 	int pos=s.find("\\end{document}");
 	if (pos>=0 && pos<ss){
-	  out << s << endl;
+	  out << s << '\n';
 	  out.close();
-	  COUT << "File " << outfile << " created, now running hevea in background and pgiac " << outfile << endl << "Then I will run pdflatex " << giac::remove_extension(outfile) << endl << "For HTML5 output, you can run\nhevea -fix " << giac::remove_extension(infile) << endl;
+	  COUT << "File " << outfile << " created, now running hevea in background and pgiac " << outfile << '\n' << "Then I will run pdflatex " << giac::remove_extension(outfile) << '\n' << "For HTML5 output, you can run\nhevea -fix " << giac::remove_extension(infile) << '\n';
 	  std::string cmd="hevea -fix "+giac::remove_extension(infile)+" &";
 	  giac::system_no_deprecation(cmd.c_str());
 	  cmd=("pgiac "+outfile+" && pdflatex "+giac::remove_extension(outfile)+" && mv "+giac::remove_extension(outfile)+".pdf "+giac::remove_extension(infile)+".pdf");
-	  COUT << cmd << endl;
+	  COUT << cmd << '\n';
 	  giac::system_no_deprecation(cmd.c_str());
 	  return;
 	}
@@ -762,7 +835,7 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	pos=s.find("\\end{giacprog}");
 	if (pos>=0 && pos<ss){
 	  prg += s.substr(0,pos);
-	  out << ".g " << prg << endl;
+	  out << ".g " << prg << '\n';
 	  s=s.substr(pos+14,ss-14-pos);
 	  inprog=false;
 	  continue;
@@ -779,7 +852,7 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
       }
       pos=s.find("\\giac");
       if (inside && pos>=0 && pos<ss){
-	out << s.substr(0,pos) << endl;
+	out << s.substr(0,pos) << '\n';
 	s=s.substr(pos,ss-pos);
 	ss=s.size();
 	bool invalid=false;
@@ -794,7 +867,7 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	  pos2=s.find("}");
 	}
 	if (ss>10 && s.substr(1,8)=="giaclink" && pos1>=0 && pos1<ss && pos2>=0 && pos2<ss){
-	  out << s.substr(0,pos2+1) << endl;
+	  out << s.substr(0,pos2+1) << '\n';
 	  s=s.substr(pos2+1,ss-pos2-1);
 	  continue;
 	}
@@ -835,7 +908,7 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	      cmd += ';'+s.substr(pos1+1,pos2-pos1-1);
 	      s=s.substr(pos2+1,ss-pos2-1);
 	      ss=s.size();
-	      out << ".g " << cmd << endl ;
+	      out << ".g " << cmd << '\n' ;
 	    }
 	  }
 	  continue;
@@ -855,32 +928,32 @@ void pgiac(std::string infile,std::string outfile,std::ostream * checkptr,std::o
 	    pos2=s.find("}");
 	  }
 	  cmd = cmd + '('+s.substr(pos1+1,pos2-pos1-1)+')';
-	  out << ".g " << cmd << endl ;
+	  out << ".g " << cmd << '\n' ;
 	  s=s.substr(pos2+1,ss-pos2-1);	
 	  continue;
 	}
 	if (pos1>0 && pos1<ss && pos2>0 && pos2<ss){
 	  string cmd=s.substr(pos1+1,pos2-pos1-1);
-	  out << ".g " << cmd << endl ;
+	  out << ".g " << cmd << '\n' ;
 	  s=s.substr(pos2+1,ss-pos2-1);
 	  continue;
 	}
 	else
-	  COUT << "Invalid giac command " << s << endl;
+	  COUT << "Invalid giac command " << s << '\n';
       }
-      out << s << endl;
+      out << s << '\n';
       break;
     }
   }
   out.close();
-  COUT << "Missing \\end{document}. File " << outfile << " created, now running pgiac" << endl;
+  COUT << "Missing \\end{document}. File " << outfile << " created, now running pgiac" << '\n';
   giac::system_no_deprecation(("pgiac "+outfile).c_str());
 }
 #endif
 
 int main(int ARGC, char *ARGV[]){    
   //giac::step_infolevel=1;
-  cerr << "// Maximum number of parallel threads " << giac::threads << endl;
+  cerr << "// Maximum number of parallel threads " << giac::threads << '\n';
   giac::context giac_context;
   giac::context * contextptr = 
     //  (giac::context *) giac::context0 ; 
@@ -888,13 +961,13 @@ int main(int ARGC, char *ARGV[]){
   bool dohevea=true;
   if (ARGC>1 && strcmp(ARGV[ARGC-1],"--pdf")==0)
     dohevea=false;
-#if !defined EMCC && !defined NSPIRE_NEWLIB
+#if !defined EMCC && !defined NSPIRE_NEWLIB && !defined KHICAS
   giac::xcasroot()=giac::xcasroot_dir(ARGV[0]);
 #endif
 #ifndef VISUALC
   signal(SIGINT,ctrl_c_signal_handler);
 #endif
-  //cerr << giac::remove_filename(ARGV[0]) << endl;
+  //cerr << giac::remove_filename(ARGV[0]) << '\n';
 #ifdef HAVE_LIBGSL
   gsl_set_error_handler_off();
 #endif
@@ -905,7 +978,7 @@ int main(int ARGC, char *ARGV[]){
     Fl::gl_visual(FL_RGB | FL_DEPTH | FL_ACCUM | FL_ALPHA);
 #endif
   giac::secure_run=false;
-#if !defined EMCC && !defined NSPIRE_NEWLIB
+#if !defined EMCC && !defined NSPIRE_NEWLIB && !defined KHICAS
   if (ARGC==2 && !strcmp(ARGV[1],"--rebuild-help-cache")){
     // works with old version of hevea (1.10) but not with hevea 2.29
     for (int i=0;i<=4;++i)
@@ -948,8 +1021,8 @@ int main(int ARGC, char *ARGV[]){
   }
 #endif
   if (ARGC==2 && (string(ARGV[1])=="-v" || string(ARGV[1])=="--version" ) ){
-    cout << "// (c) 2001, 2018 B. Parisse & others" << endl;
-    cout << GIAC_VERSION << endl;
+    cout << "// (c) 2001, 2018 B. Parisse & others" << '\n';
+    cout << GIAC_VERSION << '\n';
 #ifndef GNUWINCE
     return 0;
 #endif
@@ -975,21 +1048,21 @@ int main(int ARGC, char *ARGV[]){
     int t=atoi(getenv("GIAC_THREADS"));
     if (t>=1){
       giac::threads=t;
-      *logptr(contextptr) << "Setting threads to " << t << endl;
+      *logptr(contextptr) << "Setting threads to " << t << '\n';
     }
   }
   if (getenv("GIAC_FFTMUL_SIZE")){
     int t=atoi(getenv("GIAC_FFTMUL_SIZE"));
     if (t>=1){
       giac::FFTMUL_SIZE=t;
-      *logptr(contextptr) << "Setting FFT mult size to " << t << endl;
+      *logptr(contextptr) << "Setting FFT mult size to " << t << '\n';
     }
   }
   if (getenv("GIAC_MIN_PROBA_TIME")){
     double t=atof(getenv("GIAC_MIN_PROBA_TIME"));
     if (t>=0){
       giac::min_proba_time=t;
-      *logptr(contextptr) << "Setting minimal probabilistic answer time delat to " << t << endl;
+      *logptr(contextptr) << "Setting minimal probabilistic answer time delat to " << t << '\n';
     }
   }
   if (savedbg)
@@ -1018,7 +1091,7 @@ int main(int ARGC, char *ARGV[]){
 	  outfile=ARGV[2];
       }
       if (!giac::is_file_available(infile.c_str())){
-	COUT << "Unable to read " << infile << endl;
+	COUT << "Unable to read " << infile << '\n';
 	return 1;
       }
       pgiac(infile,outfile,checkptr,checkptrin,dohevea);
@@ -1054,7 +1127,7 @@ int main(int ARGC, char *ARGV[]){
 	outfile=ARGV[3];
     }
     if (!giac::is_file_available(infile.c_str())){
-      COUT << "Unable to read " << infile << endl;
+      COUT << "Unable to read " << infile << '\n';
       return 1;
     }
     pgiac(infile,outfile,checkptr,checkptrin,dohevea);
@@ -1079,9 +1152,9 @@ int main(int ARGC, char *ARGV[]){
 #endif
   if (giac::debug_infolevel){
     if (!helpitems)
-      cerr << "Unable to open help file aide_cas" << endl;
+      cerr << "Unable to open help file aide_cas" << '\n';
     else
-      cerr << "Registered " << helpitems << " commands" << endl;
+      cerr << "Registered " << helpitems << " commands" << '\n';
   }
   giac::set_language(giac::language(contextptr),contextptr);
 
@@ -1089,7 +1162,7 @@ int main(int ARGC, char *ARGV[]){
    * EMACS *
    *********/
   // #define EMACS_DEBUG 1
-#if !defined EMCC && !defined NSPIRE_NEWLIB
+#if !defined EMCC && !defined NSPIRE_NEWLIB && !defined KHICAS
   if (inemacs){
     giac::html_help_init(ARGV[0],false);
     int out_handle;
@@ -1124,9 +1197,9 @@ int main(int ARGC, char *ARGV[]){
 	car=i;
 #ifdef EMACS_DEBUG
 	if (i<32)
-	  logfile << "Ctrl-" << i << endl;
+	  logfile << "Ctrl-" << i << '\n';
 	else
-	  logfile << car << endl;
+	  logfile << car << '\n';
 #endif
 	if (i==EOF)
 	  break;
@@ -1155,7 +1228,7 @@ int main(int ARGC, char *ARGV[]){
 	  buffer=buffer.substr(0,s);
 	}
 #ifdef EMACS_DEBUG
-	logfile << buffer << " " << s << " " << int(buffer[buffer.size()-1]) <<endl;
+	logfile << buffer << " " << s << " " << int(buffer[buffer.size()-1]) <<'\n';
 #endif
 	if (cmd==EMACS_ASK_COMPLETION){
 	  // reading possible completions from aide_cas
@@ -1179,7 +1252,7 @@ int main(int ARGC, char *ARGV[]){
 	  int l=s;
 	  int vs=vres.size();
 #ifdef EMACS_DEBUG
-	  logfile << vs << " completions" << endl;
+	  logfile << vs << " completions" << '\n';
 #endif
 	  for (int k=0;k<vs;k++){
 	    if (common.empty()){
@@ -1189,7 +1262,7 @@ int main(int ARGC, char *ARGV[]){
 	    else {
 	      int maxl=min(common.size(),vres[k].size());
 #ifdef EMACS_DEBUG
-	      logfile << maxl << " " << common << " " << vres[k] << endl;
+	      logfile << maxl << " " << common << " " << vres[k] << '\n';
 #endif
 	      for (l=s;l<maxl;++l){
 		if (common[l]!=vres[k][l])
@@ -1283,19 +1356,20 @@ int main(int ARGC, char *ARGV[]){
      ********************************************************* */
   if ( intexmacs){
     giac::html_help_init(ARGV[0],false);
+    giac::enable_texmacs_compatible_latex_export(true);
     int out_handle;
 #ifdef WITH_GNUPLOT
     giac::run_gnuplot(out_handle);
 #endif
     putchar(TEXMACS_DATA_BEGIN);
-    printf("verbatim:");
+    // printf("verbatim:");
+    // format_plugin();
+    printf("latex:");
     format_plugin();
-    printf("--------------------------------------------------------------------\n");
-    printf("|     Giac CAS for TeXmacs, released under the GPL license (3.0)    |\n");
-    printf("|     See http://www.gnu.org for license details                    |\n");
-    printf("|  May contain BSD licensed software parts (lapack, atlas, tinymt)  |\n");
-    printf("| (c) 2003,2018 B. Parisse & al (giac), J. van der Hoeven (TeXmacs) |\n");
-    printf("--------------------------------------------------------------------\n");
+    printf("{\\centering\\begin{tabular}{|c|}\\hline Giac CAS for TeXmacs, released under the GPL license (3.0)\\\\See \\url{http://www.gnu.org} for license details\\\\May contain BSD licensed software parts (lapack, atlas, tinymt)\\\\\\copyright\\ 2003--2019 B. Parisse \\& al (giac), J. van der Hoeven (TeXmacs)\\\\\\hline\\end{tabular}\\par}");
+    putchar(TEXMACS_DATA_END);
+    putchar(TEXMACS_DATA_BEGIN);
+    printf("verbatim:\n\n");
     switch (giac::xcas_mode(contextptr)){
     case 0:
       printf("Xcas (C-like) syntax mode\n");
@@ -1318,7 +1392,7 @@ int main(int ARGC, char *ARGV[]){
       char car;//,nxt;
       for (;;){
 	int i=getchar();
-	// cerr << i << endl;
+	// cerr << i << '\n';
 	if (i==EOF)
 	  break;
 	car=i;
@@ -1332,7 +1406,7 @@ int main(int ARGC, char *ARGV[]){
 #if !defined VISUALC && !defined __MINGW_H
 	  giac::set_nonblock_flag(STDIN_FILENO,0); // set blocking mode on stdin
 #endif
-	  // cerr << "read "  << s << endl;
+	  // cerr << "read "  << s << '\n';
 	  if (i==EOF)
 	    break;
 	  buffer += car;
@@ -1497,22 +1571,25 @@ int main(int ARGC, char *ARGV[]){
   if (getenv("GIAC_TIME"))
     show_time=true;
   if (getenv("GIAC_TEX")){
-    cerr << "// Setting tex log" << endl;
+    cerr << "// Setting tex log" << '\n';
     show_tex=true;
   }
 #ifdef HAVE_LIBREADLINE
   if (ARGC==1){
+    int taillemax=1000;
+    if (getenv("GIAC_TAILLEMAX"))
+      taillemax=atoi(getenv("GIAC_TAILLEMAX"));
     struct tms start, end;  
     using_history();
-    cout << "Welcome to giac readline interface" << endl;
-    cout << "(c) 2001,2018 B. Parisse & others" << endl;
-    cout << "Homepage http://www-fourier.ujf-grenoble.fr/~parisse/giac.html" << endl;
-    cout << "Released under the GPL license 3.0 or above" << endl;
-    cout << "See http://www.gnu.org for license details" << endl;
-    cout << "May contain BSD licensed software parts (lapack, atlas, tinymt)" << endl;
-    cout << "-------------------------------------------------" << endl;
-    cout << "Press CTRL and D simultaneously to finish session" << endl;
-    cout << "Type ?commandname for help" << endl;
+    cout << "Welcome to giac readline interface" << '\n';
+    cout << "(c) 2001,2018 B. Parisse & others" << '\n';
+    cout << "Homepage http://www-fourier.ujf-grenoble.fr/~parisse/giac.html" << '\n';
+    cout << "Released under the GPL license 3.0 or above" << '\n';
+    cout << "See http://www.gnu.org for license details" << '\n';
+    cout << "May contain BSD licensed software parts (lapack, atlas, tinymt)" << '\n';
+    cout << "-------------------------------------------------" << '\n';
+    cout << "Press CTRL and D simultaneously to finish session" << '\n';
+    cout << "Type ?commandname for help" << '\n';
     for (int count=0;;++count) {
       char * res=rl_gets(count);
       if (!res)
@@ -1581,21 +1658,18 @@ int main(int ARGC, char *ARGV[]){
 	  cout << "Plot cancelled or unable to plot";
       }
       else {
-	int taillemax=1000;
-	if (getenv("GIAC_TAILLEMAX"))
-	  taillemax=atoi(getenv("GIAC_TAILLEMAX"));
-	string s=taille(ge,taillemax)>taillemax?"Done":ge.print(contextptr);
+	string s=(!insage && taille(ge,taillemax)>taillemax)?"Done":ge.print(contextptr);
 	cout << s;
       }
-      cout << endl;
+      cout << '\n';
 #ifdef HAVE_SIGNAL_H_OLD
-      cerr << giac::messages_to_print << endl;
+      cerr << giac::messages_to_print << '\n';
 #endif
       if (show_time){
 #ifdef __APPLE__
-	cerr << "// dclock1 " << double(startc)/CLOCKS_PER_SEC << endl;
+	cerr << "// dclock1 " << double(startc)/CLOCKS_PER_SEC << '\n';
 #endif
-	cerr << "// Time " << giac::delta_tms(start,end) << endl;
+	cerr << "// Time " << giac::delta_tms(start,end) << '\n';
       }
 #ifdef HAVE_EQASCII
       struct Tgraph *graph=(Tgraph *)malloc(sizeof(struct Tgraph));
@@ -1681,7 +1755,7 @@ int main(int ARGC, char *ARGV[]){
     giac::parser_filename(ARGV[1],contextptr);
   giac::readargs(ARGC,ARGV,v,contextptr);
 #ifdef HAVE_SIGNAL_H_OLD
-  cerr << giac::messages_to_print << endl;
+  cerr << giac::messages_to_print << '\n';
   bool resultat=(giac::messages_to_print=="\n");
 #else
   bool resultat=false;
@@ -1698,7 +1772,7 @@ int main(int ARGC, char *ARGV[]){
     std::string filename;
     unsigned startc;
     if (command==-1){
-      cout << "\\begin{equation} \\label{eq:d_" << st << "_" << i << "}" << endl;
+      cout << "\\begin{equation} \\label{eq:d_" << st << "_" << i << "}" << '\n';
       cout << giac::gen2tex(gq,contextptr)  ;
 #ifdef __APPLE__
       startc=clock();
@@ -1709,11 +1783,11 @@ int main(int ARGC, char *ARGV[]){
 #endif
 #ifdef HAVE_SIGNAL_H_OLD
       if (!giac::messages_to_print.empty())
-	cerr << giac::messages_to_print << endl;
+	cerr << giac::messages_to_print << '\n';
 #endif
       if ((gq.type==giac::_SYMB) && (gq!=e))
 	cout << " = " << giac::gen2tex(e,contextptr) ;
-      cout << " \\end{equation} " << endl;
+      cout << " \\end{equation} " << '\n';
     }
     else {
       if (command>0)
@@ -1727,48 +1801,48 @@ int main(int ARGC, char *ARGV[]){
 #endif
 #ifdef HAVE_SIGNAL_H_OLD
       if (!giac::messages_to_print.empty())
-	cerr << giac::messages_to_print << endl;
+	cerr << giac::messages_to_print << '\n';
 #endif
       if (showcommand)
-	cout << "// " << *it << endl;
+	cout << "// " << *it << '\n';
       cout << e.print(contextptr) ;
       if (it+1!=itend){
 	if ( (it->type!=giac::_SYMB) || (it->_SYMBptr->sommet!=giac::at_comment)) 
-	  cout << "," <<endl ;
+	  cout << "," <<'\n' ;
       }
       else
-	cout << endl;
+	cout << '\n';
 #if !defined VISUALC && ! defined __MINGW_H
       times(&f2);
       if (show_time){
 #ifdef __APPLE__
-	cerr << "// dclock2 " << double(startc)/CLOCKS_PER_SEC << endl;
+	cerr << "// dclock2 " << double(startc)/CLOCKS_PER_SEC << '\n';
 #endif
-	cerr << "// Time " << giac::delta_tms(f1,f2) << endl;
+	cerr << "// Time " << giac::delta_tms(f1,f2) << '\n';
       }
 #endif
       if (show_tex) { // append to session.tex
-	texlog << "\\begin{equation} \\label{eq:d_" << st << "_" << i << "}" << endl;
+	texlog << "\\begin{equation} \\label{eq:d_" << st << "_" << i << "}" << '\n';
 	texlog << giac::gen2tex(gq,contextptr);
 	if ((gq.type==giac::_SYMB) && (gq!=e))
 	  texlog << " = " << giac::gen2tex(e,contextptr) ;
-	texlog << " \\end{equation} " << endl;
+	texlog << " \\end{equation} " << '\n';
       }
     } // end if (command==-1) else
     giac::history_out(contextptr).push_back(e); 
   }
-  // cerr << messages_to_print << endl;
+  // cerr << messages_to_print << '\n';
   // ofstream ans((string("ans")+giac::cas_suffixe).c_str());
-  // ans << e << endl;
+  // ans << e << '\n';
 #if !defined VISUALC && !defined __MINGW_H
   times(&end);
   if (command==-1){
-    cout << giac::tex_end << endl;
-    cout << "% Generated by cas2tex in " << giac::delta_tms(start,end) << endl;
+    cout << giac::tex_end << '\n';
+    cout << "% Generated by cas2tex in " << giac::delta_tms(start,end) << '\n';
   }
   else {
     if (show_time)
-      cerr << "// Total time " << giac::delta_tms(start,end) << endl;
+      cerr << "// Total time " << giac::delta_tms(start,end) << '\n';
   }
 #endif
 #ifdef WITH_GNUPLOT
@@ -1778,3 +1852,4 @@ int main(int ARGC, char *ARGV[]){
     giac::release_globals();
   return resultat;
 }
+#endif // KHICAS
