@@ -237,16 +237,23 @@ namespace giac {
       return gensizeerr(contextptr);
     gen xval=x._IDNTptr->eval(1,x,contextptr);
     if (xval!=x){
+#if 1
+      identificateur tmpid(x._IDNTptr->id_name+string("_"));
+      gen tmp(tmpid);
+      gen g(subst(g_,x,tmp,false,contextptr));
+      return residue(g,tmp,a,contextptr);
+#else
       _purge(x,contextptr);
       xval=x._IDNTptr->eval(1,x,contextptr);
-      if (xval!=x){
+      if (xval!=x){	
 	string s="Unable to purge "+x.print(contextptr)+ ", choose another free variable name";
-	*logptr(contextptr) << s << endl;
+	*logptr(contextptr) << s << '\n';
 	return gensizeerr(s);
       }
       gen res=residue(g_,x,a,contextptr);
       sto(xval,x,contextptr);
       return res;
+#endif
     }
     gen g1=fxnd(g_);
     if (g1.type==_VECT && g1._VECTptr->size()==2){
@@ -497,7 +504,7 @@ namespace giac {
       polynome Dp_content;
       gen extra_div=1;
       if (!factor(Dp,Dp_content,fd,false,true,true,1,extra_div) || extra_div!=1){
-	*logptr(contextptr) << gettext("Unable to factor ") << r2sym(Dp,vX,contextptr) << endl;
+	*logptr(contextptr) << gettext("Unable to factor ") << r2sym(Dp,vX,contextptr) << '\n';
 	res=undef;
 	return true;
       }
@@ -506,7 +513,7 @@ namespace giac {
       factorization::const_iterator f_it=fd.begin(),f_itend=fd.end();
       for (;f_it!=f_itend;++f_it){
 	if (f_it->fact.degree(0)>1){
-	  *logptr(contextptr) << gettext("Unable to factor ") << r2sym(f_it->fact,vX,contextptr) << endl;
+	  *logptr(contextptr) << gettext("Unable to factor ") << r2sym(f_it->fact,vX,contextptr) << '\n';
 	  res=undef;
 	  return true;
 	}
@@ -799,7 +806,7 @@ namespace giac {
 	  for (int i=0;i<s;++i){
 	    if (is_real(v[i],contextptr)){
 	      res=undef; // singularity on the real axis
-	      *logptr(contextptr) << gettext("Warning: pole at ") << v[i] << endl;
+	      *logptr(contextptr) << gettext("Warning: pole at ") << v[i] << '\n';
 	      purgenoassume(gt,contextptr);
 	      return false;
 	    }
@@ -891,7 +898,7 @@ namespace giac {
       return true;
     }
     if (a==unsigned_inf || b==unsigned_inf){
-      *logptr(contextptr) << gettext("Please use +infinity or -infinity since infinity is unsigned") << endl;
+      *logptr(contextptr) << gettext("Please use +infinity or -infinity since infinity is unsigned") << '\n';
       return false;
     }
     if (is_strictly_greater(a,b,contextptr)){
@@ -1028,7 +1035,7 @@ namespace giac {
       if (heav.type==_VECT && heav._VECTptr->size()==2 && heav._VECTptr->back().type==_INT_ ){
 	int diracorder=heav._VECTptr->back().val;
 	if (diracorder<0){
-	  *logptr(contextptr) << gettext("Negative second Dirac argument") << endl;
+	  *logptr(contextptr) << gettext("Negative second Dirac argument") << '\n';
 	  return false;
 	}
 	A=derive(A,x,diracorder,contextptr);
@@ -1046,7 +1053,7 @@ namespace giac {
       if (ck_is_greater(c,a,contextptr) && ck_is_greater(b,c,contextptr))
 	res += quotesubst(A,x,c,contextptr);
       else
-	*logptr(contextptr) << gettext("Warning, Dirac function outside summation interval") << endl;
+	*logptr(contextptr) << gettext("Warning, Dirac function outside summation interval") << '\n';
       return true;
     }
     if (a==b){
@@ -1073,7 +1080,7 @@ namespace giac {
       if (b==plus_inf){
 	vecteur singu=find_singularities(g,*x._IDNTptr,0 /* real singularities*/,contextptr);
 	if (!singu.empty()){
-	  *logptr(contextptr) << "Warning, singularities at " << singu << endl;
+	  *logptr(contextptr) << "Warning, singularities at " << singu << '\n';
 	  if (calc_mode(contextptr)==1 || abs_calc_mode(contextptr)==38){
 	    res=undef;
 	    return true;
@@ -1135,7 +1142,7 @@ namespace giac {
       return false;
     } // end a==minus_inf
     if (b==plus_inf){
-      gen ga=subst(g,x,x+a,false,contextptr);
+      gen ga_orig=subst(g,x,x+a,false,contextptr),ga(ga_orig);
       // additional check for int(t^n/(exp(alpha*t)-1),t,0,inf)=n!/alpha^(n+1)*Zeta(n+1)
       vecteur vax=rlvarx(ga,x);
       if (vax.size()==2 && vax.front()==x && vax.back().is_symb_of_sommet(at_exp)){
@@ -1214,6 +1221,7 @@ namespace giac {
 	  }
 	} // end if (is_linear_wrt(expo...))
       } // end varx.size()==2
+      ga=ga_orig;
       int eo=is_even_odd(ga,x,contextptr);
       if (eo==1){ 
 	vecteur singu=find_singularities(g,*x._IDNTptr,0 /* real singularities*/,contextptr);
@@ -1360,7 +1368,7 @@ namespace giac {
 	      // complex_mode(b,contextptr);
 	      // Sucess! Now integration of gof on the unit circle using residues
 	      if (debug_infolevel)
-		*logptr(contextptr) << gettext("Searching int of ") << gof << gettext(" where ") << x << gettext(" is on the unit circle, using residues") << endl;
+		*logptr(contextptr) << gettext("Searching int of ") << gof << gettext(" where ") << x << gettext(" is on the unit circle, using residues") << '\n';
 	      // replace x by another variable because we might have assumptions on x
 	      identificateur tmpid("_intgab38");
 	      vecteur w=singular(subst(gof,x,tmpid,false,contextptr),tmpid,contextptr);
@@ -1496,7 +1504,7 @@ namespace giac {
 
   static bool sumab_ps(const polynome & Q,const polynome & R,const vecteur & v,const gen & a,const gen & x,const gen & g,bool est_reel,const polynome & p,const polynome & s,gen & res,GIAC_CONTEXT){
     // p corresponds to derivation, s to integration
-    // cerr << "p=" << p << " s=" << s << " Q=" << Q << " R=" << R << endl;
+    // cerr << "p=" << p << " s=" << s << " Q=" << Q << " R=" << R << '\n';
     // Q must be independant of x
     // If R is independant of x we use the geometric series
     // If R=x-integer the exponential (must change bounds by integer)
@@ -1649,7 +1657,7 @@ namespace giac {
 	  gen tmp=r2e(p,v,contextptr)*pow(gx,x,contextptr);
 	  gen remains,tmp1=sum(tmp,x,remains,contextptr);
 	  if (!is_zero(remains) || is_undef(tmp1)){
-	    *logptr(contextptr) << gettext("Unable to sum ")+remains.print(contextptr) << endl;
+	    *logptr(contextptr) << gettext("Unable to sum ")+remains.print(contextptr) << '\n';
 	    return false;
 	  }
 	  tmp1=-subst(tmp1,x,a,false,contextptr);
@@ -1977,7 +1985,7 @@ namespace giac {
       if (ck_is_greater(c,a_orig,contextptr) && ck_is_greater(b_orig,c,contextptr))
 	res += quotesubst(A,x,c,contextptr);
       else
-	*logptr(contextptr) << gettext("Warning, Dirac function outside summation interval") << endl;
+	*logptr(contextptr) << gettext("Warning, Dirac function outside summation interval") << '\n';
       return true;
     }
     // detect Heaviside 
