@@ -23,6 +23,9 @@
 #include "gen.h"
 #include "unary.h"
 #include "symbolic.h"
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
 
 #ifndef NO_NAMESPACE_GIAC
 namespace giac {
@@ -56,6 +59,7 @@ namespace giac {
   extern const unary_function_ptr * const  at_lcoeff ;
   extern const unary_function_ptr * const  at_set_language ;
   extern const unary_function_ptr * const  at_float ;
+  gen _build_complex(const gen & args,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_complex ;
 
   gen _tcoeff(const gen & args,GIAC_CONTEXT);
@@ -71,6 +75,7 @@ namespace giac {
   gen _dfc2f(const gen & g,GIAC_CONTEXT);
   gen _float2rational(const gen & g,GIAC_CONTEXT);
   gen _gramschmidt(const gen & g,GIAC_CONTEXT);
+  gen _fmod(const gen & g,GIAC_CONTEXT);
   gen _pmin(const gen & g,GIAC_CONTEXT);
   gen _potential(const gen & g,GIAC_CONTEXT);
   gen _vpotential(const gen & g,GIAC_CONTEXT);
@@ -237,6 +242,7 @@ namespace giac {
   extern const unary_function_ptr * const  at_histogram;
   extern const unary_function_ptr * const  at_bitand;
   extern const unary_function_ptr * const  at_bitor;
+  extern const unary_function_ptr * const  at_bitnot;
   extern const unary_function_ptr * const  at_bitxor;
   extern const unary_function_ptr * const  at_hamdist;
   matrice effectifs(const vecteur & v,double class_minimum,double class_size,GIAC_CONTEXT);
@@ -252,7 +258,9 @@ namespace giac {
   // step by step utilities
   // poi=point of interest, tvi=table of variation
   // asym=list of asymptotes, crit=critical points, inflex=inflection points
-  int step_func(const gen & f,const gen & x,gen & xmin,gen&xmax,vecteur & poig,vecteur & tvi,gen & periode,vecteur & asym,vecteur & parab,vecteur & crit,vecteur & inflex,bool printtvi,bool exactlegende,GIAC_CONTEXT,bool do_inflex=true);
+  // bit 0 of do_inflex_tabsign = set to 1 for inflexion (valid for tabvar)
+  // bit 1 of do_inflex_tabsign = set to 1 for tabsign, 0 for tabvar
+  int step_func(const gen & f,const gen & x,gen & xmin,gen&xmax,vecteur & poig,vecteur & tvi,gen & periode,vecteur & asym,vecteur & parab,vecteur & crit,vecteur & inflex,bool printtvi,bool exactlegende,GIAC_CONTEXT,int do_inflex_tabsign=1);
   extern const unary_function_ptr * const  at_tabvar;
   int step_param(const gen & f,const gen & g,const gen & t,gen & tmin,gen&tmax,vecteur & poi,vecteur & tvi,bool printtvi,bool exactlegende,GIAC_CONTEXT);
   // translate HTML Xcas for Firefox link to a giac list of commands
@@ -273,6 +281,7 @@ namespace giac {
   extern const unary_function_ptr * const  at_coth ;
   extern const unary_function_ptr * const  at_atan2 ;
   extern const unary_function_ptr * const  at_get_pixel ;
+  gen _set_pixel(const gen & args,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_set_pixel ;
   extern const unary_function_ptr * const  at_strip ;
   extern const unary_function_ptr * const  at_lower ;
@@ -282,8 +291,35 @@ namespace giac {
   extern const unary_function_ptr * const  at_isnan ;
   extern const unary_function_ptr * const  at_draw_string ;
   extern const unary_function_ptr * const  at_dtype ;
+  extern const unary_function_ptr * const  at_rgb ;
+  extern const unary_function_ptr * const  at_prediction;
+  extern const unary_function_ptr * const  at_prediction95;
+  extern const unary_function_ptr * const  at_confidence;
+  extern const unary_function_ptr * const  at_sin_regression;
+  extern const unary_function_ptr * const  at_sin_regression_plot;
+  gen _rgb(const gen & args,GIAC_CONTEXT);
+  gen _charpoly(const gen & args,GIAC_CONTEXT);
+  extern bool freeze;
+  void draw_rectangle(int x, int y, int width, int height, unsigned short color,GIAC_CONTEXT);
+  void draw_polygon(std::vector< std::vector<int> > & v1,int color,GIAC_CONTEXT);
+  void draw_filled_polygon(std::vector< std::vector<int> > &L,int xmin,int xmax,int ymin,int ymax,int color,GIAC_CONTEXT);
+  void draw_line(int x1, int y1, int x2, int y2, int color,GIAC_CONTEXT);
+  void set_pixel(int x,int y,int c,GIAC_CONTEXT);
+  void draw_circle(int xc,int yc,int r,int color,bool q1,bool q2,bool q3,bool q4,GIAC_CONTEXT);
+  void draw_filled_circle(int xc,int yc,int r,int color,bool left,bool right,GIAC_CONTEXT);
+  void draw_arc(int xc,int yc,int rx,int ry,int color,double t1, double t2,bool q1,bool q2,bool q3,bool q4,GIAC_CONTEXT);
+  void draw_arc(int xc,int yc,int rx,int ry,int color,double theta1, double theta2,GIAC_CONTEXT);
+  void draw_filled_arc(int x,int y,int rx,int ry,int theta1_deg,int theta2_deg,int color,int xmin,int xmax,int ymin,int ymax,bool segment,GIAC_CONTEXT);
 
   std::string fetch(const std::string & url);
+
+  // 4x4 matrix utilities on double, for trig regression
+  void Tran4(double * colmat);
+  void Mult4(double * colmat,double * vect,double * res);
+  void Mult4(double * c,double k,double * res);
+  double Det4(double * c);
+  void Inv4(double * c,double * res);
+
 #ifndef NO_NAMESPACE_GIAC
 } // namespace giac
 #endif // NO_NAMESPACE_GIAC
