@@ -78,7 +78,7 @@ namespace giac {
 	}
 	gen gi=env->coeff.makegen(i);
 	gen evaluation=horner(ddfactor,gi,env);
-	// CERR << gi << ":" << evaluation << endl;
+	// CERR << gi << ":" << evaluation << '\n';
 	if ( is_zero(evaluation) ){
 	  modpoly linearfact(x);
 	  linearfact=linearfact-gi*one();
@@ -204,7 +204,7 @@ namespace giac {
     // here resptr points to the highest coeff of x^i in the array res[maxdeg]
     if (env->moduloon){
       for (;resptr!=res-1;--resptr){
-	// COUT << *resptr << " " << env->modulo << endl;
+	// COUT << *resptr << " " << env->modulo << '\n';
 	if (!is_zero(smod(*resptr,env->modulo)))
 	  break;   
       }
@@ -262,7 +262,7 @@ namespace giac {
       // compute x^(pn^i) mod qrem then gcd(x^pn^i-x,qrem)
       // since X^(pn^i)-X is divisible by 
       // any irreductible of degre dividing i
-      // COUT << modulo << " " << qmat << endl;
+      // COUT << modulo << " " << qmat << '\n';
       if (qmat.empty())
 	xpi=powmod(xpower1(),pow(env->pn,i),qrem,env);
       else {
@@ -285,8 +285,8 @@ namespace giac {
 
   bool cantor_zassenhaus(const modpoly & ddfactor,int i,const vector<modpoly> & qmat,environment * env,vector<modpoly> & v){
     if (debuglevel)
-      COUT << "Factoring [" << i << "] " << ddfactor << endl 
-	// << " " << qmat << endl
+      COUT << "Factoring [" << i << "] " << ddfactor << '\n' 
+	// << " " << qmat << '\n'
 	;
     int k=int(ddfactor.size())-1; 
     if (k==i){
@@ -320,7 +320,7 @@ namespace giac {
       deg = 2*i-1;
       modpoly pp(random(deg,env));
       if (debuglevel)
-	COUT << "Degree:" << deg << ":" << pp << endl ;
+	COUT << "Degree:" << deg << ":" << pp << '\n' ;
       // we have pp^(pn^i-1)=1 mod p,q
       // factoring we get (pp^(pn^i-1)/2-1)(pp^(pn^i+1)/2+1)=0 mod p,q
       // the exponent of the first factor may be rewritten
@@ -365,7 +365,7 @@ namespace giac {
       // hopefully it will split ddfactor
       deg=int(fact1.size())-1;
     }
-    // COUT << "cz:" << i << fact1 << ddfactor/fact1 << endl;
+    // COUT << "cz:" << i << fact1 << ddfactor/fact1 << '\n';
     // recursive calls
     if (!cantor_zassenhaus(fact1,i,thisqmat,env,v) || 
 	!cantor_zassenhaus(operator_div(ddfactor,fact1,env),i,thisqmat,env,v))
@@ -375,7 +375,7 @@ namespace giac {
 
   bool cantor_zassenhaus(const vector< facteur<modpoly> > & v_in,const vector<modpoly> & qmat, environment * env,vector<modpoly> & v){
     // split elements of v_in
-    // COUT << v_in << endl;
+    // COUT << v_in << '\n';
     vector< facteur<modpoly> >::const_iterator it=v_in.begin(),itend=v_in.end();
     for (;it!=itend;++it){
       if (!cantor_zassenhaus(it->fact,it->mult,qmat,env,v))
@@ -397,24 +397,24 @@ namespace giac {
     gen tcoeff(lastnonzero(q));
     gen bound=gen( 2)*abs(lcoeff*tcoeff,context0);
     gen modulo_orig(env->modulo),moduloi(env->modulo),modulonext(env->modulo);
-    // COUT << modulo << endl;
+    // COUT << modulo << '\n';
     while (is_greater(bound,moduloi,context0)) { // (moduloi<=bound){
       modulonext=moduloi*moduloi;
       vecteur::iterator it=v.begin(),itend=v.end();
       for (;it!=itend;++it){
 	env->modulo=modulonext;
 	if (debug_infolevel>=20)
-	  CERR << "liftroot old root value " << *it << endl;
+	  CERR << "liftroot old root value " << *it << '\n';
 	gen temp1(iquo(horner(q,*it,env),moduloi));
 	if (debug_infolevel>=20)
-	  CERR << "liftroot num " << temp1 << endl;
+	  CERR << "liftroot num " << temp1 << '\n';
 	env->modulo=moduloi;
 	gen temp2(horner(qprime,*it,env));
 	if (debug_infolevel>=20)
-	  CERR << "liftroot den " << temp2 << " mod " << env->modulo << endl;
+	  CERR << "liftroot den " << temp2 << " mod " << env->modulo << '\n';
 	*it=smod(*it - moduloi* temp1 * invmod(temp2,env->modulo),modulonext) ;
 	if (debug_infolevel>=20)
-	  CERR << "liftroot new root value " << *it << endl;
+	  CERR << "liftroot new root value " << *it << '\n';
       }
       moduloi=modulonext;
       env->modulo=moduloi;
@@ -432,7 +432,7 @@ namespace giac {
       int deg=v[j].mult; // degree of this equal degree factor
       int mult=int(v[j].fact.size()-1)/deg; // number of equal degree factors
       if (debuglevel)
-	COUT << "Distinct degree factor of " << mult << " factors of deg " << deg << endl;
+	COUT << "Distinct degree factor of " << mult << " factors of deg " << deg << '\n';
       i = i + mult;
       for (int k=maxdeg-1;k>-1;k--){
 	if (possible_degrees[k]){
@@ -455,7 +455,7 @@ namespace giac {
     for (int tmp=0;tmp<=qdeg;tmp++)
       if (possible_degrees[tmp])
 	COUT << tmp << " ";
-    COUT << endl;
+    COUT << '\n';
   }
 
   // number of true elements
@@ -502,9 +502,9 @@ namespace giac {
       mulmodpoly(test,lcoeff,env,test);
       gen z=_lgcd(test,context0);
       divmodpoly(test,z,0,test);
-      // COUT << "Trying " << q << "/" << *it << endl;
+      // COUT << "Trying " << q << "/" << *it << '\n';
       if (DenseDivRem(q,test,quo,rem,true) && (rem.empty())){
-	// COUT << "Found early factor " << *it << endl;
+	// COUT << "Found early factor " << *it << '\n';
 	polynome temp=unmodularize(test);
 	q=quo;
 	v_out.push_back(temp);
@@ -519,7 +519,7 @@ namespace giac {
 	}
       }
       else {
-	// COUT << "No luck for this one!" << endl;
+	// COUT << "No luck for this one!" << '\n';
 	w_in.push_back(*it);
 	w_orig.push_back(*orig_it);
       }
@@ -542,7 +542,7 @@ namespace giac {
   // returns -1 on error
   static int liftq(environment * env,dense_POLY1 & q,gen &bound,vector<modpoly> & v_in,vectpoly & v_out,vector<bool> & possible_degrees){
     if (debuglevel)
-      COUT << "Big data -> using quadratic Hensel lift." << v_in.size() << endl;
+      COUT << "Big data -> using quadratic Hensel lift." << v_in.size() << '\n';
     gen lcoeff(q.front());
     bool notunit=(!is_one(lcoeff));
     bool testfortruefs;
@@ -551,8 +551,8 @@ namespace giac {
     if (!egcd(v_in,env,u))
       return -1;
     if (debuglevel){
-      COUT << "Lifting v_in:" << v_in << endl << "u:" << u << endl;
-      COUT << "Modulo:" << env->modulo << " Bound:" << bound << endl;
+      COUT << "Lifting v_in:" << v_in << '\n' << "u:" << u << '\n';
+      COUT << "Modulo:" << env->modulo << " Bound:" << bound << '\n';
     }
     int n=int(v_in.size());
     int nfact_to_find = n;
@@ -580,7 +580,7 @@ namespace giac {
       env->moduloon=true;
       // _VECTute Q such that q=lcoeff*(pi+p^k*Q)
       // modulo=modulonext; // work in Z/p^(2), done by modularize below
-      // COUT << "Q:" << Q << endl;
+      // COUT << "Q:" << Q << '\n';
       // _VECTute new v_in
       if (Q.empty())
 	env->modulo=modulonext;
@@ -613,12 +613,12 @@ namespace giac {
 	    }
 	    int debut_time=CLOCK();
 	    if (debuglevel)
-	      COUT << debut_time << "Searching true factor" << endl;
+	      COUT << debut_time << "Searching true factor" << '\n';
 	    // test if *itv divides q in Z
 	    if ( testfortruefs && !hasbeentested[i] && DenseDivRem(newq,truefact,tmp1,tmp2,true) && (tmp2.empty()) ){
 	      int fin_time=CLOCK();
 	      if (debuglevel)
-		COUT << fin_time << "Found true factor " << *itv << endl << "New bound:"<< bound << endl;
+		COUT << fin_time << "Found true factor " << *itv << '\n' << "New bound:"<< bound << '\n';
 	      // yes! _VECTute new q and bound
 	      truefactor[i]=true;
 	      nfact_to_find--;
@@ -641,7 +641,7 @@ namespace giac {
 	    else {
 	      int fin_time=CLOCK();
 	      if (debuglevel)
-		COUT << fin_time << "No luck!" << endl;
+		COUT << fin_time << "No luck!" << '\n';
 	      if (testfortruefs)
 		hasbeentested[i]=true;
 	    }
@@ -649,7 +649,7 @@ namespace giac {
 	}
       }
       if (debuglevel)
-	COUT << "Lifted to " << modulonext << endl;
+	COUT << "Lifted to " << modulonext << '\n';
       if ( is_strictly_greater(modulonext,bound,context0) ) // (modulonext>bound) )
 	break;
       v_orig=v_in;
@@ -694,7 +694,7 @@ namespace giac {
 	  scalarprod = scalarprod + u[k]*pidown[n-2-k]*piup[k-1];
 	  }
 	  scalarprod=scalarprod+u[n-1]*piup[n-2]-one(); // this is 0 mod modulonext
-	  COUT << "Modulo" << modulo << ", verif v_in.u:" << scalarprod << endl;
+	  COUT << "Modulo" << modulo << ", verif v_in.u:" << scalarprod << '\n';
 	  }
 	*/
 	moduloi=modulonext;
@@ -713,10 +713,10 @@ namespace giac {
     for (int i=0;i<n;i++)
       if (!truefactor[i])
 	if (!hasbeentested[i]){
-	  // COUT << "Testing 1 combinations" << endl;
+	  // COUT << "Testing 1 combinations" << '\n';
 	  return 1;
 	}
-    // COUT << "Skipping 1 combinations" << endl;
+    // COUT << "Skipping 1 combinations" << '\n';
     return 2; // all linear factors have still been tested
   }
 
@@ -731,8 +731,8 @@ namespace giac {
     if (!egcd(v_orig,env,u))
       return false;
     if (debuglevel){
-      COUT << "Lifting v_in:" << v_in << endl << "u:" << u << endl;
-      COUT << "Modulo:" << env->modulo << "Bound" << bound << endl;
+      COUT << "Lifting v_in:" << v_in << '\n' << "u:" << u << '\n';
+      COUT << "Modulo:" << env->modulo << "Bound" << bound << '\n';
     }
     int n=int(v_in.size());
     int d=int(q.size())-1;
@@ -762,7 +762,7 @@ namespace giac {
 	return false;
       if (notunit)
 	mulmodpoly(Q,invmod(lcoeff,env->modulo),env,Q); // Q=Q*invmod(lcoeff);
-      // COUT << "Q:" << Q << endl;
+      // COUT << "Q:" << Q << '\n';
       // compute new v_in
       if (Q.empty()){
 	env->modulo=modulonext;
@@ -783,7 +783,7 @@ namespace giac {
 	moduloi=modulonext;
       }
       if (debuglevel)
-	COUT << "Lifted to " << modulonext << endl;
+	COUT << "Lifted to " << modulonext << '\n';
     }
     return true;
   }
@@ -795,7 +795,7 @@ namespace giac {
       return; // nothing to do
     int n=int(v_in.size());
     if (debuglevel)
-      COUT << CLOCK() << "Starting combining with " << n << " factors" << endl;
+      COUT << CLOCK() << "Starting combining with " << n << " factors" << '\n';
     gen lcoeff(smod(q.front(),env->modulo));
     bool notunit=(!is_one(lcoeff));
     if (n==1){
@@ -820,10 +820,10 @@ namespace giac {
     gen dminus1bound((norm(q,0)+1)*gen((int)q.size()-1)*lcoeff);
     gen dminus1bound_=iquo(dminus1bound*twoto32,env->modulo);
     int d1=dminus1bound_.to_int()+1; // maxvalue of d-1 coeff for a product
-    // COUT << dminus1bound << endl;
+    // COUT << dminus1bound << '\n';
     for (;k<n;k++){
       if (debuglevel)
-	COUT << CLOCK() << "Testing combination of " << k << " factors" << endl;
+	COUT << CLOCK() << "Testing combination of " << k << " factors" << '\n';
       // initialize all iterators, picstcoeff[] and totaldeg[]
       it[1]=v_in.begin();
       // product of cst coeff
@@ -887,7 +887,7 @@ namespace giac {
 	    if (notunit)
 	      mulmodpoly(pi,lcoeff,env,pi);
 	    dense_POLY1 quo(1),rem(1);
-	    // COUT << pi << " " << combination << endl;
+	    // COUT << pi << " " << combination << '\n';
 	    if (notunit)
 	      ppz(pi);
 	    if ( // (gen(2)*abs(pi[2])<dminus1bound*gen((int)q.size()-2)) &&
@@ -948,7 +948,7 @@ namespace giac {
 	      break;
 	  }
 	  if (debuglevel && (j<k/2))
-	    COUT << CLOCK() << " " << _VECTteur << " tries." << endl;
+	    COUT << CLOCK() << " " << _VECTteur << " tries." << '\n';
 	  // if j!=0, recalculate successors, picstcoeff and totaldeg
 	  if (j){
 	    lastpi=picstcoeff[j-1];
@@ -1107,44 +1107,44 @@ namespace giac {
 	  return 0;
 	mulmodpoly(Q,invmod(lcoeff,env->modulo),env,Q); // Q=Q*invmod(lcoeff) Q is now unitary
 	if (debug_infolevel>=20)
-	  CERR << "linearfind: trying with prime " << m << " for " << Q << endl;
+	  CERR << "linearfind: trying with prime " << m << " for " << Q << '\n';
 	if (is_one(gcd(Q,derivative(Q,env),env)))
 	  break;
       }
     }
     if (i==100) return 0; // setsizeerr(gettext("modfactor.cc/linearfind")); 
     if (debug_infolevel>=20)
-      CERR << "linearfind: using prime " << m << endl;
+      CERR << "linearfind: using prime " << m << '\n';
     vecteur w,xpuipn(xpowerpn(env));
     vector<modpoly> wtmp;
     if (is_undef(xpuipn)) return 0;
     if (!roots((pn>0 && signed(Q.size())>pn)?gcd(Q,operator_minus(xpuipn,xpower1(),env),env):Q,env,w,wtmp))
       return 0;
     if (debug_infolevel>=20)
-      CERR << "linearfind modular roots " << w << endl;
+      CERR << "linearfind modular roots " << w << '\n';
     dense_POLY1 q1(modularize(q,gen(0),env));
     if (is_undef(q1)) return 0;
     liftroots(q1,env,w);
     if (debug_infolevel>=20)
-      CERR << "linearfind lifted modular roots " << w << endl;
+      CERR << "linearfind lifted modular roots " << w << '\n';
     // try each element of w
     vecteur::const_iterator it=w.begin(),itend=w.end();
     for (;it!=itend;++it){
       dense_POLY1 combination,quo,rem;
       if (notunit){
-	// COUT << *it << " " << lcoeff << " " << env->modulo << endl;
+	// COUT << *it << " " << lcoeff << " " << env->modulo << '\n';
 	gen s( smod((*it)*lcoeff,env->modulo) );
 	gen g(gcd(s,lcoeff,context0));
 	combination.push_back(iquo(lcoeff,g));
 	combination.push_back(iquo(-s,g));
-	// COUT << combination << endl;
+	// COUT << combination << '\n';
       }
       else {
 	combination.push_back(gen( 1));
 	combination.push_back(smod(-(*it),env->modulo));
       }
       if (debug_infolevel>=20)
-	CERR << "checking " << combination << endl;
+	CERR << "checking " << combination << '\n';
       if (DenseDivRem(q1,combination,quo,rem,true) && (rem.empty())){
 	// push factor found
 	v.push_back(unmodularize(combination));
@@ -1186,7 +1186,7 @@ namespace giac {
     gen bound=mignotte_bound(q)*abs(lcoeff,context0) ;
     double logbound_d=bound.bindigits()*giac_log((double) 2);
     if (debuglevel>=2)
-      COUT << "Bound " << bound << " log:" << logbound_d << endl;
+      COUT << "Bound " << bound << " log:" << logbound_d << '\n';
     modpoly Qtry(1);
     int bestprime=0,bestnumberoffactors=0;
     gen bestliftsteps;
@@ -1206,7 +1206,7 @@ namespace giac {
 	if (is_undef(Qtry))
 	  return false;
 	Qtry=operator_times(invmod(lcoeff,env->modulo),Qtry,env); // -> Q is now unitary
-	// COUT << "Trying with " << m << Q << endl;
+	// COUT << "Trying with " << m << Q << '\n';
 	if (is_one(gcd(Qtry,derivative(Qtry,env),env))){
 	  vector< facteur<modpoly> > wftry;
 	  // distinct degree factorization of Qtry mod env->modulo
@@ -1215,7 +1215,7 @@ namespace giac {
 	  if (!ddf(Qtry,qmat,env,wftry))
 	    return false;
 	  if (debuglevel)
-	    COUT << "Trying prime " << env->modulo << endl;
+	    COUT << "Trying prime " << env->modulo << '\n';
 	  vector<bool> new_degrees(qdeg+1);
 	  int numberoffactors;
 	  if (essai){
@@ -1236,11 +1236,11 @@ namespace giac {
 	  int ilifta=int(giac_ceil(giac_log(logbound_d/giac_log((double) primes[i]))/giac_log(2.0)));
 	  int iliftb=giacmax(1,int(giac_ceil(giac_log(2./3.*logbound_d/giac_log((double) primes[i]))/giac_log(2.))));
 	  if (debuglevel)
-	    COUT << "Would use min " << ilifta << "," << iliftb << " steps modulo " << currentprime << endl; 
+	    COUT << "Would use min " << ilifta << "," << iliftb << " steps modulo " << currentprime << '\n'; 
 	  gen qlifta(pow(currentprime,(long unsigned int) pow(gen(2),ilifta).to_int()));
 	  gen qliftb(pow(currentprime,(long unsigned int) 3*pow(gen(2),iliftb-1).to_int()));
 	  if (debuglevel>=2)
-	    COUT << "Would use min " << qlifta << "," << endl << qliftb << " modulo " << currentprime << endl; 
+	    COUT << "Would use min " << qlifta << "," << '\n' << qliftb << " modulo " << currentprime << '\n'; 
 	  gen liftsteps;
 	  if (is_strictly_greater(qliftb,qlifta,context0)) // (qlifta<qliftb)
 	    liftsteps=qlifta;
@@ -1260,15 +1260,15 @@ namespace giac {
 	}
 	else // non sqff
 	  if (debuglevel)
-	    COUT << "Not square-free modulo " << currentprime <<endl;
+	    COUT << "Not square-free modulo " << currentprime <<'\n';
       } 
       else // degree non cst
 	if (debuglevel)
-	  COUT << "Non constant degree modulo " << currentprime << endl;
+	  COUT << "Non constant degree modulo " << currentprime << '\n';
     }
     env->modulo=gen(bestprime);
     if (debuglevel){
-      COUT << "Using prime " << env->modulo << endl;
+      COUT << "Using prime " << env->modulo << '\n';
       if (debuglevel>=2){
 	COUT << " for " ;
 	dbgprint(q);
@@ -1277,7 +1277,7 @@ namespace giac {
     vector<modpoly> w;
     if (!cantor_zassenhaus(wf,bestqmat,env,w))
       return false;
-    // COUT << "Starting lift" << endl;
+    // COUT << "Starting lift" << '\n';
     // lift and combine
     dense_POLY1 q1(modularize(q,gen(0),env));
     if (is_undef(q1))
@@ -1310,7 +1310,7 @@ namespace giac {
     }
     env->moduloon=false;
     if (debuglevel)
-      COUT << CLOCK() << "End combine" << endl;
+      COUT << CLOCK() << "End combine" << '\n';
     return true;
   }
 
@@ -1320,20 +1320,20 @@ namespace giac {
 
   int ntlfactor(inttype *p, int pdeg,inttype ** result,int * resultdeg,int debug=0){
     if (debug_infolevel)
-      CERR << CLOCK()*1e-6 << " NTL factor begin" << endl;
+      CERR << CLOCK()*1e-6 << " NTL factor begin" << '\n';
     NTL::ZZX f(tab2ZZX(p,pdeg));
-    // COUT << "Factoring " << f << endl;
+    // COUT << "Factoring " << f << '\n';
     NTL::vec_pair_ZZX_long factors;
     NTL::ZZ c;
     factor(c, factors, f,debug); // c will be 0 since q has content 1
     // convert factors to arrays, multiplicity is always 1
-    // COUT << factors << endl;
+    // COUT << factors << '\n';
     int s=factors.length();
     for (int i=0;i<s;i++){
       ZZX2tab(factors[i].a,resultdeg[i],result[i]);
     }
     if (debug_infolevel)
-      CERR << CLOCK()*1e-6 << " NTL factor end" << endl;
+      CERR << CLOCK()*1e-6 << " NTL factor end" << '\n';
     return s;
   }
   // ithprime will not be used here
@@ -1353,9 +1353,9 @@ namespace giac {
 	delete [] tab;
 	return false;
       }
-      // CERR << "NTL factor begins" << endl;
+      // CERR << "NTL factor begins" << '\n';
       int size=ntlfactor(tab,n,result,resultdeg,debug); 
-      // CERR << "NTL factor end" << endl;
+      // CERR << "NTL factor end" << '\n';
       // size is the number of poly in result
       for (long i = 0 ; i < size; i++){
 	v.push_back(tab2polynome(result[i],resultdeg[i]));
